//缓存处理

/**
 * 获取本地缓存
 * function callback(cacheSize, errorInfo):
 */
function getCacheSize(callback) {
	var formatedSize;
	if(plus.os.name == "Android") {
		plus.android.importClass("java.io.File");
		formatedSize = formatSize(calcCache4Android());
		return callback(formatedSize, null);
	} else if(plus.os.name == "iOS") {
		calcCache(function(size) {
			formatedSize = formatSize(size);
			return callback(formatedSize, null);
		});
	} else {
		return callback(0, "未知的设备类型,无法计算缓存");
	}
}

function formatSize(size) {
	var fileSizeString;
	size = parseInt(size);
	console.log("缓存大小：" + size);
	if(size <= 0) {
		fileSizeString = "0B";
	} else if(size < 1024) {
		fileSizeString = size + "B";
	} else if(size < 1048576) {
		fileSizeString = (size / 1024).toFixed(2) + "KB";
	} else if(size < 1073741824) {
		console.log("Mb" + size);
		fileSizeString = (size / 1048576).toFixed(2) + "MB";
		console.log("/ after" + fileSizeString);
	} else {
		fileSizeString = (size / 1073741824).toFixed(2) + "GB";
	}
	return fileSizeString;
}
function calcCache4Android() {
	var cacheSize = 0;
	console.log("start calc android");
	var main = plus.android.runtimeMainActivity();
	var sdRoot = main.getCacheDir();
	console.log(sdRoot.getAbsolutePath());
	var files = plus.android.invoke(sdRoot, "listFiles");
	cacheSize += getFolderSize(files);
	console.log("android size-->" + cacheSize);
	return cacheSize;
}
function getFolderSize(files) {
	var size = 0;
	var len = files.length;
	for(var i = 0; i < len; i++) {
		// 如果下面还有文件
		if(files[i].isDirectory()) {
			var dirs = plus.android.invoke(files[i], "listFiles");
			size = size + getFolderSize(dirs);
		} else if(!files[i].isHidden()) {
			size = size + files[i].length();
		}
	}
	return size;
}

/**
 * 计算缓存大小  官方提供方法，用于iOS
 */
function calcCache(callback) {
	console.log("开始计算缓存大小");
	plus.cache.calculate(function(size) {
		console.log(size + "byte");
		var sizeInt = parseInt(size);
		console.log("sizeInt: " + sizeInt);
		return callback(sizeInt);
	});
}

/**
 * 清除缓存
 * callback():
 */
function clearCache(callback){
	if(plus.os.name == "Android") {
		clearCacheAndroid();
		return callback();
	} else if(plus.os.name == "iOS") {
		plus.cache.clear(callback);
	}
}
function clearCacheAndroid() {
	console.log("清理所有缓存");
	plus.android.importClass("java.io.File");
	var main = plus.android.runtimeMainActivity();
	console.log("main" + main.getCacheDir());
	var sdRoot = main.getCacheDir();
	var files = plus.android.invoke(sdRoot, "listFiles");
	deleteDir(files);
}

function deleteDir(files) {
	var len = files.length;
	console.log("len:" + len);
	for(var i = 0; i < len; i++) {
		console.log("delete file dir:" + files[i]);
		// 如果下面还有文件
		if(files[i].isDirectory()) {
			var dirs = plus.android.invoke(files[i], "listFiles");
			deleteDir(dirs);
		} else if(!files[i].isHidden()) {
			files[i].delete();
		}
	}
}
