/**
 * ===========================
 * 日期时间工具
 * ===========================
 * 2017-03-14
 */


/**
 * 计算两个时间戳间的差值
 * @param {Object} timeStampStart: 开始时间戳
 * @param {Object} timeStampEnd
 */
function calculateTimeDifference(timeStampStart, timeStampEnd){
	var difference = timeStampStart - timeStampEnd;  //时间差的毫秒数
	
	//计算出相差天数
	var days = Math.floor(difference/(24*3600*1000));
	//计算出小时数
	var leave1 = difference % (24*3600*1000);//计算天数后剩余的毫秒数
	var hours = Math.floor(leave1/(3600*1000));
	//计算相差分钟数
	var leave2 = leave1%(3600*1000);//计算小时数后剩余的毫秒数
	var minutes = Math.floor(leave2/(60*1000));
	//计算相差秒数
	var leave3 = leave2%(60*1000);//计算分钟数后剩余的毫秒数
	var seconds = Math.round(leave3/1000);
	
	var timeDiff = [days, hours];
	return timeDiff;
}

/**
 * 格式化时间（HH:mm）
 * @param {Object} timeStamp
 */
function formatNowTime() {
	// 将/[0-9]/位的数字编成/0[0-9]/
	function getTwo(s) {
		if(parseInt(s) < 10) {
			return "0" + s;
		} else {
			return "" + s;
		}
	}
	var timeStamp = new Date().getTime();
	if(timeStamp != null && timeStamp.length < 13) {
		timeStamp += "000";
	}
	var d = new Date(parseInt(timeStamp));

	var year = d.getFullYear();
	var month = getTwo(d.getMonth() + 1);
	var date = getTwo(d.getDate());
	var hour = getTwo(d.getHours());
	var minute = getTwo(d.getMinutes());
	var second = getTwo(d.getSeconds());

	return hour + ":" + minute;
}

/**
 * 格式化时间（yyyy-MM-dd）
 * @param {Object} timeStamp
 */
function formatDate(timeStamp) {
	if(!timeStamp) {
		return "未知";
	}
	// 将/[0-9]/位的数字编成/0[0-9]/
	function getTwo(s) {
		if(parseInt(s) < 10) {
			return "0" + s;
		} else {
			return "" + s;
		}
	}

	if(timeStamp != null && timeStamp.length < 13) {
		timeStamp += "000";
	}
	var d = new Date(parseInt(timeStamp));

	var year = d.getFullYear();
	var month = getTwo(d.getMonth() + 1);
	var date = getTwo(d.getDate());

	return year + "-" + month + "-" + date;
}

/**
 * 格式化时间（yyyy-MM）
 * @param {Object} timeStamp
 */
function formatMonth(timeStamp) {
	if(!timeStamp) {
		return "未知";
	}
	// 将/[0-9]/位的数字编成/0[0-9]/
	function getTwo(s) {
		if(parseInt(s) < 10) {
			return "0" + s;
		} else {
			return "" + s;
		}
	}

	if(timeStamp != null && timeStamp.length < 13) {
		timeStamp += "000";
	}
	var d = new Date(parseInt(timeStamp));

	var year = d.getFullYear();
	var month = getTwo(d.getMonth() + 1);

	return year + "-" + month;
}

/**
 * 格式化时间（HH:mm）
 * @param {Object} timeStamp
 */
function formatTime(timeStamp) {
	if(!timeStamp) {
		return "未知";
	}
	// 将/[0-9]/位的数字编成/0[0-9]/
	function getTwo(s) {
		if(parseInt(s) < 10) {
			return "0" + s;
		} else {
			return "" + s;
		}
	}

	if(timeStamp.length < 13) {
		timeStamp += "000";
	}
	var d = new Date(parseInt(timeStamp));

	var year = d.getFullYear();
	var month = getTwo(d.getMonth() + 1);
	var date = getTwo(d.getDate());
	var hour = getTwo(d.getHours());
	var minute = getTwo(d.getMinutes());
	var second = getTwo(d.getSeconds());

	return hour + ":" + minute;
}

/**
 * 格式化时间（yyyy-MM-dd HH:mm:ss）
 * @param {Object} timeStamp
 */
function formatDateTime(timeStamp) {
	if(!timeStamp) {
		return "未知";
	}
	// 将/[0-9]/位的数字编成/0[0-9]/
	function getTwo(s) {
		if(parseInt(s) < 10) {
			return "0" + s;
		} else {
			return "" + s;
		}
	}

	if(timeStamp.length < 13) {
		timeStamp += "000";
	}
	var d = new Date(parseInt(timeStamp));

	var year = d.getFullYear();
	var month = getTwo(d.getMonth() + 1);
	var date = getTwo(d.getDate());
	var hour = getTwo(d.getHours());
	var minute = getTwo(d.getMinutes());
	var second = getTwo(d.getSeconds());

	return year + "-" + month + "-" + date + " " + hour + ":" + minute;
}

/**
 * 格式化时间（yyyy-MM-dd）
 * @param {Object} timeStamp
 */
function formatDateShow(timeStamp) {
	if(!timeStamp) {
		return "";
//		return "未知";
	}
	// 将/[0-9]/位的数字编成/0[0-9]/
	function getTwo(s) {
		if(parseInt(s) < 10) {
			return "0" + s;
		} else {
			return "" + s;
		}
	}

	if(timeStamp != null && timeStamp.length < 13) {
		timeStamp += "000";
	}
	timeStamp = parseInt(timeStamp);
	var nowDate = new Date();
	var nowTimeStamp = nowDate.getTime();
	var d = new Date(parseInt(timeStamp));
	//接收时间大于当前时间
	if(nowTimeStamp < timeStamp){
		return getTwo(d.getHours()) + ":" + getTwo(d.getMinutes());
	}
	//当天内
	if(formatDate(timeStamp) == formatDate(nowTimeStamp)){
		return getTwo(d.getHours()) + ":" + getTwo(d.getMinutes());
	}
	//昨天
	if(formatDate(timeStamp+24*60*60*1000) == formatDate(nowTimeStamp)){
		return "昨天";
	}
	//前天
	if(formatDate(timeStamp+2*24*60*60*1000) == formatDate(nowTimeStamp)){
		return "前天";
	}

	var year = d.getFullYear();
	var month = getTwo(d.getMonth() + 1);
	var date = getTwo(d.getDate());
	var hour = getTwo(d.getHours());
	var minute = getTwo(d.getMinutes());
	var second = getTwo(d.getSeconds());
	
	return year + "-" + month + "-" + date;
}