/**
 * 判断应用升级模块，从url地址下载升级描述文件到本地local路径
 * yanyilin@dcloud.io
 * 
 * 升级文件为JSON格式数据，如下：
{
	"appid":"HelloH5",
    "iOS":{
    	"version":"iOS新版本号，如：1.0.0",
    	"note":"iOS新版本描述信息，多行使用\n分割",
    	"url":"Appstore路径，如：itms-apps://itunes.apple.com/cn/app/hello-h5+/id682211190?l=zh&mt=8"
    },
    "Android":{
    	"version":"Android新版本号，如：1.0.1",
    	"note":"Android新版本描述信息，多行使用\n分割",
    	"url":"apk文件下载地址，如：http://www.dcloud.io/helloh5p/HelloH5.apk"
    }
}
 *
 */
(function(w){
	//var server="http://dev-webapi.jm.com/webapi/v1",//获取升级描述文件服务器地址
	localDir="update",localFile="update.json",//本地保存升级描述目录和文件名
	keyUpdate="updateCheck",//取消升级键名
	keyAbort="updateAbort",//忽略版本键名
	checkInterval=86400000,//升级检查间隔，单位为ms,2天为2*24*60*60*1000=172800000, 如果每次启动需要检查设置值为0
	dir=null;
	
	/**
	 * 准备升级操作
	 * 创建升级文件保存目录
	 */
	function initUpdate(){
		// 在IOS或者流应用模式下不需要检测升级操作
		if(plus.os.name == "iOS" || navigator.userAgent.indexOf('StreamApp')>=0){
			return;
		}
		// 打开doc根目录
		plus.io.requestFileSystem( plus.io.PRIVATE_DOC, function(fs){
			fs.root.getDirectory( localDir, {create:true}, function(entry){
				dir = entry;
				checkUpdate();
			}, function(e){
				console.log( "准备升级操作，打开update目录失败："+e.message );
			});
		},function(e){
			console.log( "准备升级操作，打开doc目录失败："+e.message );
		});
	}
	
	/**
	 * 检测程序升级
	 */
	function checkUpdate() {
		// 判断升级检测是否过期
		var lastcheck = plus.storage.getItem( keyUpdate );
		if ( lastcheck ) {
			var dc = parseInt( lastcheck );
			var dn = (new Date()).getTime();
			if ( dn-dc < checkInterval ) {	// 未超过上次升级检测间隔，不需要进行升级检查
				return;
			}
			// 取消已过期，删除取消标记
			plus.storage.removeItem( keyUpdate );
		}
		// 从服务器获取升级数据
		getUpdateData();
	}
	
	/**
	 * 检查升级数据
	 */
	function checkUpdateData( data ){
		var curVer=plus.runtime.version;
		console.log(curVer);
		if ( data ){
			var srvVer = data.version;
			// 判断是否存在忽略版本号
			var vabort = plus.storage.getItem( keyAbort );
			if ( vabort && srvVer==vabort ) {
				// 忽略此版本
				return;
			}
			// 判断是否需要升级
			if ( compareVersion(curVer, srvVer) ) {
				// 提示用户是否升级
				plus.nativeUI.confirm( data.note, function(i){
					if ( 0==i.index ) {
						plus.runtime.openURL( data.url );
					}else {
						//plus.storage.setItem( keyUpdate, (new Date()).getTime().toString() );
					}
				}, data.title, ["立即更新", "取消提示"] );
			}
			plus.storage.setItem( keyUpdate, (new Date()).getTime().toString() );
		}
	}
	
	/**
	 * 从服务器获取升级数据
	 */
	function getUpdateData(callback){
		var params = {
			clientType: plus.os.name,
			updateType: "1"
		};
		webCall2("/compus/appversion/getAppVersioList", params, 1001, function success(data, requestCode){
			if(data && data.data){
				if(callback){
					callback(data.data);
				}else{
					checkUpdateData(data.data);
				}
			}
		}, function error(resultCode, resultMsgDesc){
		});
	}
	
	/**
	 * 比较版本大小，如果新版本nv大于旧版本ov则返回true，否则返回false
	 * @param {String} ov
	 * @param {String} nv
	 * @return {Boolean} 
	 */
	function compareVersion( ov, nv ){
		if ( !ov || !nv || ov=="" || nv=="" ){
			return false;
		}
		var b=false;
		var ova = ov.split(".",4);
		var nva = nv.split(".",4);
		for ( var i=0; i<ova.length&&i<nva.length; i++ ) {
			var so=ova[i],no=parseInt(so),sn=nva[i],nn=parseInt(sn);
			if ( nn>no || sn.length>so.length  ) {
				return true;
			} else if ( nn<no ) {
				return false;
			}
		}
		if ( nva.length>ova.length && 0==nv.indexOf(ov) ) {
			return true;
		}
		return false;
	}
	
	if ( w.plus ) {
		initUpdate();
	} else {
		document.addEventListener("plusready", initUpdate, false );
	}
	
	/** 
	 * window.getAppVersion(从服务器端获取版本信息) 提供给外部使用
	 * getAppVersion(versionData): 返回版本数据
	 */
	window.getAppVersion = getUpdateData;
	/**
	 * 是否有新版本
	 * isHaveNewVersion(currentVersion, newestVersion): 入参为当前版本、最新版本
	 */
	window.isHaveNewVersion = compareVersion;//
})(window);