/**
 * 语音识别初始化入口函数
 * @param {Object} type 0 科大讯飞语音(默认)，1 百度语音
 */
function initSpeech(type) {
	if(plus.os.name == "iOS") {
		initiOSSpeech(type);
	} else {
		initAndroidSpeech(type);
	}
}
/**
 * iOS初始化语音识别模块
 * @param {Object} type 0 科大讯飞语音(默认)，1 百度语音
 */
function initiOSSpeech(type) {
	var barcode;
	if (type && 1 == type) {
		barcode = 'BDSpeech';
	} else {
		barcode = 'IFlySpeech';
	}
	var bridge = window.plus.bridge;
	var iosSpeech = { 
		/**
		 * 开始语音识别
		 */
		startListen: function(successCallback, errorCallback) {
			var success = typeof successCallback !== 'function' ? null : function(args) {
					successCallback(args);
				},
				fail = typeof errorCallback !== 'function' ? null : function(code) {
					errorCallback(code);
				};
			var callbackID = bridge.callbackId(success, fail);

			return bridge.exec(barcode, "startListen", [callbackID]);
		},

		/**
		 * 停止语音识别
		 */
		stopListen: function(successCallback, errorCallback) {
			var success = typeof successCallback !== 'function' ? null : function(args) {
					successCallback(args);
				},
				fail = typeof errorCallback !== 'function' ? null : function(code) {
					errorCallback(code);
				};
			var callbackID = bridge.callbackId(success, fail); 

			return bridge.exec(barcode, "stopListen", [callbackID]);
		}
	};
	if (type && 1 == type) {
		window.plus.BdPlugin = iosSpeech;
	} else {
		window.plus.XFYunPlugin = iosSpeech;
	}
}

var speechRecognizer;
/**
 * 初始化语音识别
 * 进入语音识别界面时调用
 */
function initAndroidSpeech(type) {
	if (type == null || type == 0) return; // Android科大讯飞语音无需初始化
	var main = plus.android.runtimeMainActivity();
	speechRecognizer = plus.android.newObject("com.app.yunma.common.BaiduSpeechRecognizer", main);
}

/**
 * 语音识别资源释放
 * 退出语音识别界面时调用
 */
function destorySpeech(type) {
	if(type && type == 1) { // 百度
		if(plus.os.name == 'iOS') {
			plus.BdPlugin.stopListen();
		} else {
			androidDestory()
		}
	} else { // 科大讯飞
		if(plus.os.name == 'iOS') {
			plus.XFYunPlugin.stopListen();
		} else {
			plus.speech.stopRecognize();
		}
	}
}

/**
 * 停止识别
 * 在用户操作完成或点击取消时调用
 */
function stopSpeech(type) {
	if (type && type == 1) { // 百度
		if(plus.os.name == "iOS") {
			plus.BdPlugin.stopListen();
		} else {
			stopAndroidSpeech();
		}
	} else { // 科大讯飞
		if(plus.os.name == "iOS") {
			plus.XFYunPlugin.stopListen();
		} else {
			plus.speech.stopRecognize();
		}
	}
}

/**
 * 设置回调
 */
function setAndroidSpeechCallback(recognizerCallBack) {
	plus.android.invoke(speechRecognizer, "setCallBack", recognizerCallBack);
}
/**
 * 启动语音识别（百度）
 */
function startAndroidSpeech() {
	plus.android.invoke(speechRecognizer, "start");
}

/**
 * 停止识别（百度）
 */
function stopAndroidSpeech() {
	plus.android.invoke(speechRecognizer, "stop");
}
/**
 * Android机器上使用百度语音时关掉界面要调用，以释放语音识别资源
 */
function androidDestory() {
	plus.android.invoke(speechRecognizer, "destory");
}
