/** 网络请求码 */
var QUERY_SCHOOL_INFO = 1002, QUERY_APP = 1003, UN_BIND_CARD = 1004;
var myScroll;
var vueObj = new Vue({
	el: '#main',
	data: {
		cardMainTopShow: false,
		wgtVersion: null,
		cardMainBg: null, //学生卡全景图
		badgeImg: null, //学校校徽
		userData: {}, //用户信息
		schoolCode: null, //学校编码
		bindCardStatus: -1, //绑卡状态 1已经绑卡 0未绑卡
		appDatas: [] //应用列表
	},
	beforeMount: function() {
		mui.init({
			//监听返回事件
			beforeback: function() {
				setUpViewStatusBar(plus.webview.currentWebview().statusBarType);
				return true;
			}
		});
		mui.plusReady(function() {
			//状态栏设置
			setStatusBarDefault();
			plus.webview.currentWebview().addEventListener("popGesture", function(e) {
				if(e.type == 'start'){ //侧滑开始
					setUpViewStatusBar(plus.webview.currentWebview().statusBarType);
				}else if(e.type == 'end' && e.result === false){ //侧滑返回取消
					setStatusBarDefault();
				}
			}, false);
			//监听用户数据变化
			window.addEventListener("onUserInfoChange", function(event){
				vueObj.initData(false);
			});
			window.addEventListener("onSchoolChange2", function(event){
				vueObj.initData(false);
				var schoolName = event.detail.schoolName;
				vueObj.schoolCode = event.detail.schoolCode;
				vueObj.userData.schoolName = schoolName;
				vueObj.pulldownRefresh(); //重新刷新数据
			});
			// 获取本地应用资源版本号
			plus.runtime.getProperty(plus.runtime.appid, function(inf) {
				vueObj.wgtVersion = inf.version;
			});
			//获取用户数据
			vueObj.initData(true);
			vueObj.cardMainTopShow = true;
		});
	},
	methods: {
		/**
		 * 初始化数据
		 */
		initData: function(loadApp) {
			vueObj.userData = getUserInfo();
			vueObj.schoolCode = getCache(SCHOOL_CODE_KEY);
			vueObj.bindCardStatus = vueObj.userData.bindCardStatus;
			if(!vueObj.schoolCode) removeCache(CARD_MAIN_BG_KEY);
			vueObj.cardMainBg = getCache(CARD_MAIN_BG_KEY);
			//查询学生卡应用
			if(!loadApp) return;
			vueObj.pulldownRefresh();
		},
		/**
		 * 下拉刷新具体业务实现
		 */
		pulldownRefresh: function(isFirst) {
			if(vueObj.schoolCode){
				//查询学校信息
				webCall2("/compus/school/getSchoolInfo", null, QUERY_SCHOOL_INFO, vueObj.onSuccess, vueObj.onErrorBefore, null, null, null, null, true);
			}
			if(!isFirst){
				//查询学生卡应用
				webCall2("/compus/application/getSchoolCardAppList", {offset:0,limit:1000}, QUERY_APP, vueObj.onSuccess, vueObj.onErrorBefore, null, null, null, null, true);
			}
		},
		/**
		 * 接口访问成功返回
		 * @param {Object} data
		 * @param {Object} requestCode
		 */
		onSuccess: function(data, requestCode) {
			switch(requestCode) {
			case QUERY_APP: //学生卡相关应用查询
				//过滤低版本应用
				var apps = []; var j = 0;
				for(var i=0; i<data.rows.length; i++){
					var app = data.rows[i];
					if(app.appCode != 'cardMain' && (!app.minVersion || !compareVersions(vueObj.wgtVersion, app.minVersion))){
						apps[j] = app; j++;
					}
				}
				vueObj.appDatas = apps;
				break;
			case QUERY_SCHOOL_INFO: //查询学校信息
				vueObj.cardMainBg = data.data.panoramagramImg;
				vueObj.badgeImg = data.data.badgeImg;
				if(!vueObj.badgeImg){
					vueObj.badgeImg = "../../img/logo.png";
				}
				setCache(CARD_MAIN_BG_KEY, vueObj.cardMainBg);
				if(!vueObj.cardMainBg){
					removeCache(CARD_MAIN_BG_KEY);
					vueObj.cardMainBg = "images/card_main_default.png";
				}
				break;
			case UN_BIND_CARD: //学生卡解绑成功
				vueObj.userData = data.data;
				updateLoginInfo(null, data.data);
				vueObj.bindCardStatus = data.data.bindCardStatus;
				//更新相关页面
				mui.fire(plus.webview.getWebviewById("home/home_main.html"), "onUserInfoChange", {doRemind:true});
				mui.fire(plus.webview.getWebviewById("center/center_main.html"), "onUserInfoChange", {});
				//跳转学校选择页
				openWindow("bindCard", "../card/bind_card.html", false, {
					statusBarType: STATUS_BAR_DEFAULT_KEY,
					from: "selectSchool"
				});
				break;
			default:
				break;
			}
			vueObj.closePullStatus();
		},
		/**
		 * 接口访问失败返回
		 * @param {Object} resultCode
		 * @param {Object} resultMsgDesc
		 */
		onErrorBefore: function(resultCode, resultMsgDesc, requestCode) {
			closeWaiting();
			vueObj.closePullStatus();
		},
		/**
		 * 关闭上拉/下拉刷新 
		 */
		closePullStatus: function(data) {
			//刷新列表
			Vue.nextTick(function(){
				myScroll.refresh();
			});
		},
		/**
		 * 按钮点击监听
		 */
		onButtonClick: function(e) {
			switch (e.currentTarget.dataset.type){
			case 'unbind': //解绑
				confirmDialog('', '确认解除绑定？', '确认', '取消', function sureCallback(){
					showWaiting();
					//调用退出登录接口
					webCall2("/compus/user/unBindCard", {}, UN_BIND_CARD, vueObj.onSuccess, vueObj.onErrorBefore, null, null, null, null, true);
				}, function cancelCallback(){
				});
				break;
			case 'bind': //去绑卡
				openBindCard();
				break;
			case 'school': //切换学校
				openWindow("selectSchool", "../login/select_school.html", false, {
					statusBarType: STATUS_BAR_DEFAULT_KEY,
					from: 'noSchool'
				}, null, true);
				break;
			default:
				break;
			}
		},
		/**
		 * 按钮点击监听
		 */
		onItemClick: function(e) {
			//添加统计事件
			statisticEvent("appClickTime", {"appName" : e.currentTarget.dataset.appname, "from" : "学生卡首页"});
			var index = e.currentTarget.dataset.index;
			var app = vueObj.appDatas[index];
			if(app.serviceUsable == 1){
				toast("学校尚未开放此功能");
				return;
			}
			if(app.validBindStatus == 0 && vueObj.bindCardStatus == 0){
				openBindCard();
				return;
			}
			if(app.appType == 0){
				openWindow("app_" + app.applicationId, app.appUrl, false, {statusBarType: STATUS_BAR_DEFAULT_KEY, appName: e.currentTarget.dataset.appname});
			}else{
				openWindow("app_" + app.applicationId, "../common/web_page.html", false, {
					webUrl: app.appUrl,
					statusBarType: STATUS_BAR_DEFAULT_KEY
				});
			}
		}
	}
});

/**iscroll下拉刷新组件初始化需要*/
(function($) {
	$(function() {
		var pullDownAction = function() {
			vueObj.pulldownRefresh();
		};
		//初始化下拉刷新
		myScroll = iscrollAssist.newVerScrollForPull('.wrapper', pullDownAction, null);
		myScroll.refresh();
	});
})(mui);