//请求码
var QUERY_LIST = 1001;
//初始化vue
var vueObj = new Vue({
	el: '#main',
	data: {
		searchTime: null,
		applicationId:null, //应用ID
		searchName:null, //学校名称搜索
		datas: [], //教育局列表
		address: null,
	},
	beforeMount: function() {
		mui.init({
			//监听返回事件
			beforeback: function() {
				setUpViewStatusBar(plus.webview.currentWebview().statusBarType);
				return true;
			}
		});
		mui.plusReady(function() {
			//设置键盘弹出模式
			keyboardAdjustResize();
			setStatusBarDefault();
			plus.webview.currentWebview().addEventListener("popGesture", function(e) {
				if(e.type == 'start'){ //侧滑开始
					setUpViewStatusBar(plus.webview.currentWebview().statusBarType);
				}else if(e.type == 'end' && e.result === false){ //侧滑返回取消
					setStatusBarDefault();
				}
			}, false);
			//监听数据变化
			window.addEventListener("onUserCityChange", function(event){
				vueObj.searchName = event.detail.city;
				vueObj.loadData();
			});
			//滚动初始化
			mui('.mui-scroll-wrapper').scroll();
			//接收参数
			vueObj.applicationId = plus.webview.currentWebview().applicationId;
			if(!vueObj.applicationId){
				vueObj.applicationId = comGetUrlParamByName(plus.webview.currentWebview().getURL(), "applicationId");
			}
			//先获取位置信息
			vueObj.getUserPosition();
		});
	},
	methods: {
		/*
		 * 获取用户位置信息
		 * 没有授权就提示去授权, 否则提示去选择地区
		 */
		getUserPosition: function() {
			if(!checkUserPermission("LOCATION", null, function(){
				vueObj.getUserPosition();
			})){
				vueObj.address = "定位失败";
				return;
			} 
			showWaiting();
			plus.geolocation.getCurrentPosition(function(p) {
				closeWaiting();
				console.log("Geolocation info: " + JSON.stringify(p));
				setCache(LOCATION_POSITION_KEY, JSON.stringify(p));
				vueObj.address = p.address.province + " " + p.address.city;
				if(p.address.city) vueObj.searchName = p.address.city;
				vueObj.loadData();
			}, function(e) {
				closeWaiting();
				console.log("Gelocation Error: code - " + e.code + "; message - " + e.message);
				toast("定位失败，请检查您的定位权限是否被禁止");
				setNoDataBackground("main", true);
			}, {
				provider: 'amap' //amap>baidu>system
			});
		},
		/**
		 * 加载数据
		 */
		loadData: function() {
			var params = {
				offset: 0,
				limit: 30,
				applicationId: vueObj.applicationId
			};
			if(vueObj.searchName) params.searchName = vueObj.searchName;
			showWaiting();
			webCall2("/compus/application/getAppEduBureauList", params, QUERY_LIST, vueObj.onSuccess, vueObj.onErrorBefore);
		},
		/*
		 * 搜索框数据变化
		 */
		inputChange: function(e){
			var keyword = e.currentTarget.value;
			if(!keyword){ //搜索框为空，则加载附近数据
				vueObj.searchName = null;
				vueObj.loadData();
				return;
			}
			if(keyword.length < 2){
				toast("请至少输入2个字");
				return;
			}
			if(vueObj.searchTime) clearTimeout(vueObj.searchTime);
			vueObj.searchTime = setTimeout(function(){
				vueObj.searchName = keyword;
				vueObj.loadData();
			}, 1000);
		}, 
		/**
		 * 选择教育局
		 */
		onSelect: function(e) {
			vueObj.appUrl = e.currentTarget.dataset.appUrl;
			if(!vueObj.appUrl) return;
			if(vueObj.appUrl.indexOf("http") == 0){
				openWindow(vueObj.appUrl, "../common/web_page.html", false, {
					webUrl: vueObj.appUrl,
					statusBarType: plus.webview.currentWebview().statusBarType
				});
			}else{
				openWindow(vueObj.appUrl, vueObj.appUrl, false, {
					statusBarType: plus.webview.currentWebview().statusBarType
				});
			}
			setTimeout(function(){
				closeWebview(plus.webview.currentWebview().id);
			}, 1000);
		},
		/**
		 * 接口访问成功返回
		 */
		onSuccess: function(data, requestCode){
			closeWaiting();
			switch(requestCode){
			case QUERY_LIST: //查询教育局列表
				vueObj.datas = data.rows;
				//无数据图
				if(vueObj.datas.length == 0) {
					setNoDataBackground("main", true);
				} else {
					setNoDataBackground("main", false);
				}
				break;
			default:
				break;
			}
		},
		/**
		 * 接口访问失败返回
		 */
		onErrorBefore: function(resultCode, resultMsgDesc){
			closeWaiting();
			onError(resultCode, resultMsgDesc);
		}
	}
});

/*
 * 选择地区按钮点击
 */
document.getElementById("changeCityBtn").addEventListener("tap", function(){
	document.activeElement.blur();
	openWindow("schoolProvince", "school_province.html", false, {statusBarType: STATUS_BAR_DEFAULT_KEY});
});

// 设置背景
function setNoDataBackground(elementId, isNoData) {
	if(isNoData) {
		document.getElementById(elementId).style.backgroundImage = "url(../../img/no_content_bg.png)";
		document.getElementById(elementId).style.backgroundSize = "100% auto";
		document.getElementById(elementId).style.backgroundRepeat = "no-repeat";
		document.getElementById(elementId).style.backgroundPosition = "center";
		document.getElementById(elementId).style.backgroundPositionY = "80px";
	} else {
		document.getElementById(elementId).style.backgroundImage = "none";
	}
}
